@@ -1,4 +1,5 @@
 #define ARMA_DONT_PRINT_ERRORS
+#define ARMA_DONT_PRINT_OPENMP_WARNING
 #include <RcppArmadillo.h>
 #include <RcppArmadilloExtensions/sample.h>
 // [[Rcpp::depends(RcppArmadillo)]]
@@ -141,6 +142,7 @@ List genOptimalDesign(arma::mat initialdesign, const arma::mat& candidatelist,co
     while((newOptimum - priorOptimum)/priorOptimum > minDelta) {
       priorOptimum = newOptimum;
       for (unsigned int i = 0; i < nTrials; i++) {
+        Rcpp::checkUserInterrupt();
         found = FALSE;
         entryx = 0;
         entryy = 0;
@@ -174,6 +176,7 @@ List genOptimalDesign(arma::mat initialdesign, const arma::mat& candidatelist,co
     while((newOptimum - priorOptimum)/priorOptimum < -minDelta) {
       priorOptimum = newOptimum;
       for (unsigned int i = 0; i < nTrials; i++) {
+        Rcpp::checkUserInterrupt();
         found = FALSE;
         entryx = 0;
         entryy = 0;
@@ -212,6 +215,7 @@ List genOptimalDesign(arma::mat initialdesign, const arma::mat& candidatelist,co
     while((newOptimum - priorOptimum)/priorOptimum < -minDelta) {
       priorOptimum = newOptimum;
       for (unsigned int i = 0; i < nTrials; i++) {
+        Rcpp::checkUserInterrupt();
         found = FALSE;
         entryx = 0;
         entryy = 0;
@@ -253,6 +257,7 @@ List genOptimalDesign(arma::mat initialdesign, const arma::mat& candidatelist,co
     while((newOptimum - priorOptimum)/priorOptimum > minDelta) {
       priorOptimum = newOptimum;
       for (unsigned int i = 0; i < nTrials; i++) {
+        Rcpp::checkUserInterrupt();
         found = FALSE;
         entryx = 0;
         entryy = 0;
@@ -307,6 +312,7 @@ List genOptimalDesign(arma::mat initialdesign, const arma::mat& candidatelist,co
         first++;
         priorOptimum = optimum;
         for (unsigned int i = 0; i < nTrials; i++) {
+          Rcpp::checkUserInterrupt();
           found = FALSE;
           entryx = 0;
           entryy = 0;
@@ -364,6 +370,7 @@ List genOptimalDesign(arma::mat initialdesign, const arma::mat& candidatelist,co
     while((newOptimum - priorOptimum)/priorOptimum < -minDelta) {
       priorOptimum = newOptimum;
       for (unsigned int i = 0; i < nTrials; i++) {
+        Rcpp::checkUserInterrupt();
         found = FALSE;
         entryx = 0;
         entryy = 0;
@@ -403,6 +410,7 @@ List genOptimalDesign(arma::mat initialdesign, const arma::mat& candidatelist,co
     while((newOptimum - priorOptimum)/priorOptimum > minDelta) {
       priorOptimum = newOptimum;
       for (unsigned int i = 0; i < nTrials; i++) {
+        Rcpp::checkUserInterrupt();
         found = FALSE;
         entryx = 0;
         entryy = 0;
@@ -437,6 +445,7 @@ List genOptimalDesign(arma::mat initialdesign, const arma::mat& candidatelist,co
     while((newOptimum - priorOptimum)/priorOptimum > minDelta) {
       priorOptimum = newOptimum;
       for (unsigned int i = 0; i < nTrials; i++) {
+        Rcpp::checkUserInterrupt();
         found = FALSE;
         entryx = 0;
         entryy = 0;
@@ -608,6 +617,7 @@ List genBlockedOptimalDesign(arma::mat initialdesign, arma::mat candidatelist, c
       priorOptimum = newOptimum;
       del = calculateBlockedDOptimality(combinedDesign,vInv);
       for (unsigned int i = 0; i < nTrials; i++) {
+        Rcpp::checkUserInterrupt();
         found = FALSE;
         entryx = 0;
         entryy = 0;
@@ -664,6 +674,7 @@ List genBlockedOptimalDesign(arma::mat initialdesign, arma::mat candidatelist, c
     while((newOptimum - priorOptimum)/priorOptimum > minDelta) {
       priorOptimum = newOptimum;
       for (unsigned int i = 0; i < nTrials; i++) {
+        Rcpp::checkUserInterrupt();
         found = FALSE;
         entryx = 0;
         entryy = 0;
@@ -727,6 +738,7 @@ List genBlockedOptimalDesign(arma::mat initialdesign, arma::mat candidatelist, c
     while((newOptimum - priorOptimum)/priorOptimum < -minDelta) {
       priorOptimum = newOptimum;
       for (unsigned int i = 0; i < nTrials; i++) {
+        Rcpp::checkUserInterrupt();
         found = FALSE;
         entryx = 0;
         entryy = 0;
@@ -851,6 +863,7 @@ List genBlockedOptimalDesign(arma::mat initialdesign, arma::mat candidatelist, c
       priorOptimum = newOptimum;
       del = calculateBlockedEOptimality(combinedDesign,vInv);
       for (unsigned int i = 0; i < nTrials; i++) {
+        Rcpp::checkUserInterrupt();
         found = FALSE;
         entryx = 0;
         entryy = 0;
